==> texinfo-6.1.tar.xz: texinfo-6.1/tp/tests/tex_html/res_parser/tex_complex_l2h/tex_complex-l2h_cache.pm <==

$l2h_cache_key = q/$$
 U w V^\dagger
$$/;
$l2h_cache{$l2h_cache_key} = q|<BR><P></P>
<DIV ALIGN="CENTER" CLASS="mathdisplay">
<!-- MATH
 \begin{displaymath}
U w V^\dagger
\end{displaymath}
 -->

<IMG
 WIDTH="100" HEIGHT="20" BORDER="0"
 SRC="tex_complex_2.png"
 ALT="\begin{displaymath}
U w V^\dagger
\end{displaymath}">
</DIV>
<BR CLEAR="ALL">
<P></P>|;

$l2h_cache_key = q/$$
\omega = h ( \eta , \varphi) 
$$/;
$l2h_cache{$l2h_cache_key} = q|<BR><P></P>
<DIV ALIGN="CENTER" CLASS="mathdisplay">
<!-- MATH
 \begin{displaymath}
\omega = h ( \eta , \varphi)
\end{displaymath}
 -->

<IMG
 WIDTH="100" HEIGHT="20" BORDER="0"
 SRC="tex_complex_3.png"
 ALT="\begin{displaymath}
\omega = h ( \eta , \varphi)
\end{displaymath}">
</DIV>
<BR CLEAR="ALL">
<P></P>|;

$l2h_cache_key = q/$$\partial_{\eta} g(\eta(t),\varphi(t));
$$/;
$l2h_cache{$l2h_cache_key} = q|<BR><P></P>
<DIV ALIGN="CENTER" CLASS="mathdisplay">
<!-- MATH
 \begin{displaymath}
\partial_{\eta} g(\eta(t),\varphi(t));
\end{displaymath}
 -->

<IMG
 WIDTH="100" HEIGHT="20" BORDER="0"
 SRC="tex_complex_1.png"
 ALT="\begin{displaymath}\partial_{\eta} g(\eta(t),\varphi(t));
\end{displaymath}">
</DIV>
<BR CLEAR="ALL">
<P></P>|;

$l2h_cache_key = q/$(I-D) \varphi(t)$/;
$l2h_cache{$l2h_cache_key} = q|<!-- MATH
 $(I-D) \varphi(t)$
 -->
<SPAN CLASS="MATH"><IMG
 WIDTH="100" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="tex_complex_4.png"
 ALT="$(I-D) \varphi(t)$"></SPAN>|;

$l2h_cache_key = q/$\phi w V^t$/;
$l2h_cache{$l2h_cache_key} = q|<SPAN CLASS="MATH"><IMG
 WIDTH="100" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="tex_complex_5.png"
 ALT="$\phi w V^t$"></SPAN>|;

$l2h_cache_key = q/$h \dot \psi^\phi$/;
$l2h_cache{$l2h_cache_key} = q|<!-- MATH
 $h \dot \psi^\phi$
 -->
<SPAN CLASS="MATH"><IMG
 WIDTH="100" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="tex_complex_6.png"
 ALT="$h \dot \psi^\phi$"></SPAN>|;
1;

==> texinfo_6.7.0.dfsg.2.orig.tar.xz: texinfo-6.7/tp/tests/tex_html/res_parser/tex_complex_l2h/tex_complex-l2h_cache.pm <==

$l2h_cache_key = q/$$
 U w V^\dagger
$$/;
$l2h_cache{$l2h_cache_key} = q|<BR><P></P>
<DIV CLASS="mathdisplay">
<!-- MATH
 \begin{displaymath}
U w V^\dagger
\end{displaymath}
 -->

<IMG STYLE=""
 SRC="tex_complex_2.svg"
 ALT="\begin{displaymath}
U w V^\dagger
\end{displaymath}">
</DIV>
<BR CLEAR="ALL">
<P></P>|;

$l2h_cache_key = q/$$
\omega = h ( \eta , \varphi) 
$$/;
$l2h_cache{$l2h_cache_key} = q|<BR><P></P>
<DIV CLASS="mathdisplay">
<!-- MATH
 \begin{displaymath}
\omega = h ( \eta , \varphi)
\end{displaymath}
 -->

<IMG STYLE=""
 SRC="tex_complex_3.svg"
 ALT="\begin{displaymath}
\omega = h ( \eta , \varphi)
\end{displaymath}">
</DIV>
<BR CLEAR="ALL">
<P></P>|;

$l2h_cache_key = q/$$\partial_{\eta} g(\eta(t),\varphi(t));
$$/;
$l2h_cache{$l2h_cache_key} = q|<BR><P></P>
<DIV CLASS="mathdisplay">
<!-- MATH
 \begin{displaymath}
\partial_{\eta} g(\eta(t),\varphi(t));
\end{displaymath}
 -->

<IMG STYLE=""
 SRC="tex_complex_1.svg"
 ALT="\begin{displaymath}\partial_{\eta} g(\eta(t),\varphi(t));
\end{displaymath}">
</DIV>
<BR CLEAR="ALL">
<P></P>|;

$l2h_cache_key = q/$(I-D) \varphi(t)$/;
$l2h_cache{$l2h_cache_key} = q|<!-- MATH
 $(I-D) \varphi(t)$
 -->
<SPAN CLASS="MATH"><IMG STYLE="height: 2.55ex; vertical-align: -0.70ex; " SRC="tex_complex_4.svg"
 ALT="$(I-D) \varphi(t)$"></SPAN>|;

$l2h_cache_key = q/$\phi w V^t$/;
$l2h_cache{$l2h_cache_key} = q|<SPAN CLASS="MATH"><IMG STYLE="height: 2.52ex; vertical-align: -0.57ex; " SRC="tex_complex_5.svg"
 ALT="$\phi w V^t$"></SPAN>|;

$l2h_cache_key = q/$h \dot \psi^\phi$/;
$l2h_cache{$l2h_cache_key} = q|<!-- MATH
 $h \dot \psi^\phi$
 -->
<SPAN CLASS="MATH"><IMG STYLE="height: 2.84ex; vertical-align: -0.57ex; " SRC="tex_complex_6.svg"
 ALT="$h \dot \psi^\phi$"></SPAN>|;
1;
